==> kvision-bootstrap-typeahead-remote-4.0.0.jar: kvision-kvision-bootstrap-typeahead-remote-jsLegacy.js <==
(function (root, factory) {
  if (typeof define === 'function' && define.amd)
    define(['exports', 'kotlin', 'kvision-jsLegacy', 'kvision-kvision-bootstrap-typeahead-jsLegacy', 'kvision-kvision-common-remote-jsLegacy', 'kotlinx-serialization-kotlinx-serialization-core-jsLegacy'], factory);
  else if (typeof exports === 'object')
    factory(module.exports, require('kotlin'), require('kvision-jsLegacy'), require('kvision-kvision-bootstrap-typeahead-jsLegacy'), require('kvision-kvision-common-remote-jsLegacy'), require('kotlinx-serialization-kotlinx-serialization-core-jsLegacy'));
  else {
    if (typeof kotlin === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-bootstrap-typeahead-remote-jsLegacy'. Its dependency 'kotlin' was not found. Please, check whether 'kotlin' is loaded prior to 'kvision-kvision-bootstrap-typeahead-remote-jsLegacy'.");
    }if (typeof this['kvision-jsLegacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-bootstrap-typeahead-remote-jsLegacy'. Its dependency 'kvision-jsLegacy' was not found. Please, check whether 'kvision-jsLegacy' is loaded prior to 'kvision-kvision-bootstrap-typeahead-remote-jsLegacy'.");
    }if (typeof this['kvision-kvision-bootstrap-typeahead-jsLegacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-bootstrap-typeahead-remote-jsLegacy'. Its dependency 'kvision-kvision-bootstrap-typeahead-jsLegacy' was not found. Please, check whether 'kvision-kvision-bootstrap-typeahead-jsLegacy' is loaded prior to 'kvision-kvision-bootstrap-typeahead-remote-jsLegacy'.");
    }if (typeof this['kvision-kvision-common-remote-jsLegacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-bootstrap-typeahead-remote-jsLegacy'. Its dependency 'kvision-kvision-common-remote-jsLegacy' was not found. Please, check whether 'kvision-kvision-common-remote-jsLegacy' is loaded prior to 'kvision-kvision-bootstrap-typeahead-remote-jsLegacy'.");
    }if (typeof this['kotlinx-serialization-kotlinx-serialization-core-jsLegacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-bootstrap-typeahead-remote-jsLegacy'. Its dependency 'kotlinx-serialization-kotlinx-serialization-core-jsLegacy' was not found. Please, check whether 'kotlinx-serialization-kotlinx-serialization-core-jsLegacy' is loaded prior to 'kvision-kvision-bootstrap-typeahead-remote-jsLegacy'.");
    }root['kvision-kvision-bootstrap-typeahead-remote-jsLegacy'] = factory(typeof this['kvision-kvision-bootstrap-typeahead-remote-jsLegacy'] === 'undefined' ? {} : this['kvision-kvision-bootstrap-typeahead-remote-jsLegacy'], kotlin, this['kvision-jsLegacy'], this['kvision-kvision-bootstrap-typeahead-jsLegacy'], this['kvision-kvision-common-remote-jsLegacy'], this['kotlinx-serialization-kotlinx-serialization-core-jsLegacy']);
  }
}(this, function (_, Kotlin, $module$kvision_jsLegacy, $module$kvision_kvision_bootstrap_typeahead_jsLegacy, $module$kvision_kvision_common_remote_jsLegacy, $module$kotlinx_serialization_kotlinx_serialization_core_jsLegacy) {
  'use strict';
  var $$importsForInline$$ = _.$$importsForInline$$ || (_.$$importsForInline$$ = {});
  var TextInputType = $module$kvision_jsLegacy.io.kvision.form.text.TextInputType;
  var AbstractText = $module$kvision_jsLegacy.io.kvision.form.text.AbstractText;
  var Kind_CLASS = Kotlin.Kind.CLASS;
  var TypeaheadInput = $module$kvision_kvision_bootstrap_typeahead_jsLegacy.io.kvision.form.text.TypeaheadInput;
  var KFunction = Kotlin.kotlin.reflect.KFunction;
  var IllegalStateException_init = Kotlin.kotlin.IllegalStateException_init_pdl1vj$;
  var TaAjaxOptions = $module$kvision_kvision_bootstrap_typeahead_jsLegacy.io.kvision.form.text.TaAjaxOptions;
  var drop = Kotlin.kotlin.text.drop_6ic1pp$;
  var utils = $module$kvision_jsLegacy.io.kvision.utils;
  var listOf = Kotlin.kotlin.collections.listOf_i5x0yv$;
  var JsonRpcRequest = $module$kvision_kvision_common_remote_jsLegacy.io.kvision.remote.JsonRpcRequest;
  var getKClass = Kotlin.getKClass;
  var createKType = Kotlin.createKType;
  var kotlin_js_internal_StringCompanionObject = Kotlin.kotlin.js.internal.StringCompanionObject;
  var serializer = $module$kotlinx_serialization_kotlinx_serialization_core_jsLegacy.kotlinx.serialization.builtins.serializer_6eet4j$;
  var ListSerializer = $module$kotlinx_serialization_kotlinx_serialization_core_jsLegacy.kotlinx.serialization.builtins.ListSerializer_swdriu$;
  var HttpType$valueOf = $module$kvision_kvision_bootstrap_typeahead_jsLegacy.io.kvision.form.text.HttpType.valueOf_61zpoe$;
  var get_set = $module$kvision_jsLegacy.io.kvision.utils.get_set_5cw0du$;
  var emptySet = Kotlin.kotlin.collections.emptySet_287e2$;
  var Regex_init = Kotlin.kotlin.text.Regex_init_61zpoe$;
  var serializer_0 = $module$kotlinx_serialization_kotlinx_serialization_core_jsLegacy.kotlinx.serialization.serializer_ca95z9$;
  var KSerializer = $module$kotlinx_serialization_kotlinx_serialization_core_jsLegacy.kotlinx.serialization.KSerializer;
  var throwCCE = Kotlin.throwCCE;
  var copyToArray = Kotlin.kotlin.collections.copyToArray;
  TypeaheadRemote.prototype = Object.create(AbstractText.prototype);
  TypeaheadRemote.prototype.constructor = TypeaheadRemote;
  TypeaheadRemoteInput.prototype = Object.create(TypeaheadInput.prototype);
  TypeaheadRemoteInput.prototype.constructor = TypeaheadRemoteInput;
  function TypeaheadRemote(serviceManager, function_0, stateFunction, items, minLength, delay, type, value, name, label, rich, init) {
    if (stateFunction === void 0)
      stateFunction = null;
    if (items === void 0)
      items = 8;
    if (minLength === void 0)
      minLength = 1;
    if (delay === void 0)
      delay = 0;
    if (type === void 0)
      type = TextInputType.TEXT;
    if (value === void 0)
      value = null;
    if (name === void 0)
      name = null;
    if (label === void 0)
      label = null;
    if (rich === void 0)
      rich = false;
    if (init === void 0)
      init = null;
    AbstractText.call(this, label, rich);
    this.stateFunction_xn32t0$_0 = stateFunction;
    var $receiver = new TypeaheadRemoteInput(serviceManager, function_0, this.stateFunction_xn32t0$_0, items, minLength, delay, type, value);
    var closure$name = name;
    $receiver.id = this.idc;
    $receiver.name = closure$name;
    this.input_rigeej$_0 = $receiver;
    this.input.eventTarget = this;
    this.addPrivate_87eobz$(this.input);
    this.addPrivate_87eobz$(this.invalidFeedback);
    init != null ? init(this) : null;
  }
  Object.defineProperty(TypeaheadRemote.prototype, 'items', {
    configurable: true,
    get: function () {
      return this.input.items;
    },
    set: function (value) {
      this.input.items = value;
    }
  });
  Object.defineProperty(TypeaheadRemote.prototype, 'minLength', {
    configurable: true,
    get: function () {
      return this.input.minLength;
    },
    set: function (value) {
      this.input.minLength = value;
    }
  });
  Object.defineProperty(TypeaheadRemote.prototype, 'showHintOnFocus', {
    configurable: true,
    get: function () {
      return this.input.showHintOnFocus;
    },
    set: function (value) {
      this.input.showHintOnFocus = value;
    }
  });
  Object.defineProperty(TypeaheadRemote.prototype, 'autoSelect', {
    configurable: true,
    get: function () {
      return this.input.autoSelect;
    },
    set: function (value) {
      this.input.autoSelect = value;
    }
  });
  Object.defineProperty(TypeaheadRemote.prototype, 'delay', {
    configurable: true,
    get: function () {
      return this.input.taAjaxOptions;
    },
    set: function (value) {
      this.input.taAjaxOptions = value;
    }
  });
  Object.defineProperty(TypeaheadRemote.prototype, 'fitToElement', {
    configurable: true,
    get: function () {
      return this.input.fitToElement;
    },
    set: function (value) {
      this.input.fitToElement = value;
    }
  });
  Object.defineProperty(TypeaheadRemote.prototype, 'type', {
    configurable: true,
    get: function () {
      return this.input.type;
    },
    set: function (value) {
      this.input.type = value;
    }
  });
  Object.defineProperty(TypeaheadRemote.prototype, 'autocomplete', {
    configurable: true,
    get: function () {
      return this.input.autocomplete;
    },
    set: function (value) {
      this.input.autocomplete = value;
    }
  });
  Object.defineProperty(TypeaheadRemote.prototype, 'input', {
    configurable: true,
    get: function () {
      return this.input_rigeej$_0;
    }
  });
  TypeaheadRemote.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'TypeaheadRemote',
    interfaces: [AbstractText]
  };
  function typeaheadRemote($receiver, serviceManager, function_0, stateFunction, items, minLength, delay, type, value, name, label, rich, init) {
    if (stateFunction === void 0)
      stateFunction = null;
    if (items === void 0)
      items = 8;
    if (minLength === void 0)
      minLength = 1;
    if (delay === void 0)
      delay = 0;
    if (type === void 0)
      type = TextInputType.TEXT;
    if (value === void 0)
      value = null;
    if (name === void 0)
      name = null;
    if (label === void 0)
      label = null;
    if (rich === void 0)
      rich = false;
    if (init === void 0)
      init = null;
    var typeaheadRemote = new TypeaheadRemote(serviceManager, function_0, stateFunction, items, minLength, delay, type, value, name, label, rich, init);
    $receiver.add_87eobz$(typeaheadRemote);
    return typeaheadRemote;
  }
  function TypeaheadRemoteInput(serviceManager, function_0, stateFunction, items, minLength, delay, type, value, taAjaxOptions, classes, init) {
    if (stateFunction === void 0)
      stateFunction = null;
    if (items === void 0)
      items = 8;
    if (minLength === void 0)
      minLength = 1;
    if (delay === void 0)
      delay = 0;
    if (type === void 0)
      type = TextInputType.TEXT;
    if (value === void 0)
      value = null;
    if (taAjaxOptions === void 0)
      taAjaxOptions = null;
    if (classes === void 0) {
      classes = emptySet();
    }if (init === void 0)
      init = null;
    TypeaheadInput.call(this, null, null, null, items, minLength, delay, type, value, classes);
    this.stateFunction_7p3yg8$_0 = stateFunction;
    this.kvUrlPrefix_6kah5n$_0 = window['kv_remote_url_prefix'];
    this.urlPrefix_c4c7g0$_0 = this.kvUrlPrefix_6kah5n$_0 != undefined ? this.kvUrlPrefix_6kah5n$_0.toString() + '/' : '';
    var tmp$, tmp$_0, tmp$_1, tmp$_2, tmp$_3;
    tmp$_2 = serviceManager.getCalls();
    var tmp$_4;
    if ((tmp$_1 = (tmp$_0 = Kotlin.isType(tmp$ = function_0, KFunction) ? tmp$ : null) != null ? tmp$_0.callableName : null) != null)
      tmp$_4 = tmp$_1;
    else {
      var tmp$_5 = function_0.toString();
      tmp$_4 = Regex_init('\\s').replace_x2uqeu$(tmp$_5, '');
    }
    tmp$_3 = tmp$_2.get_11rb$(tmp$_4);
    if (tmp$_3 == null) {
      throw IllegalStateException_init('Function not specified!');
    }var url = tmp$_3.component1()
    , method = tmp$_3.component2();
    var tempAjaxOptions = taAjaxOptions != null ? taAjaxOptions : new TaAjaxOptions();
    this.taAjaxOptions = tempAjaxOptions.copy_e0rzf$(this.urlPrefix_c4c7g0$_0 + drop(url, 1), TypeaheadRemoteInput_init$lambda(this, url), TypeaheadRemoteInput_init$lambda_0, void 0, HttpType$valueOf(method.name));
    init != null ? init(this) : null;
  }
  function TypeaheadRemoteInput_init$lambda(this$TypeaheadRemoteInput, closure$url) {
    return function (query) {
      var tmp$, tmp$_0;
      var squery = JSON.stringify(query);
      var state = (tmp$_0 = (tmp$ = this$TypeaheadRemoteInput.stateFunction_7p3yg8$_0) != null ? tmp$() : null) != null ? JSON.stringify(tmp$_0) : null;
      var $receiver = utils.JSON.plain;
      var value = new JsonRpcRequest(0, closure$url, listOf([squery, state]));
      var tmp$_1;
      return $receiver.encodeToString_tf03ej$(Kotlin.isType(tmp$_1 = serializer_0($receiver.serializersModule, createKType(getKClass(JsonRpcRequest), [], false)), KSerializer) ? tmp$_1 : throwCCE(), value);
    };
  }
  function TypeaheadRemoteInput_init$lambda_0(it) {
    return copyToArray(utils.JSON.plain.decodeFromString_awif5v$(ListSerializer(serializer(kotlin_js_internal_StringCompanionObject)), it.result));
  }
  TypeaheadRemoteInput.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'TypeaheadRemoteInput',
    interfaces: [TypeaheadInput]
  };
  function typeaheadRemoteInput($receiver, serviceManager, function_0, stateFunction, items, minLength, delay, type, value, taAjaxOptions, classes, className, init) {
    if (stateFunction === void 0)
      stateFunction = null;
    if (items === void 0)
      items = 8;
    if (minLength === void 0)
      minLength = 1;
    if (delay === void 0)
      delay = 0;
    if (type === void 0)
      type = TextInputType.TEXT;
    if (value === void 0)
      value = null;
    if (taAjaxOptions === void 0)
      taAjaxOptions = null;
    if (classes === void 0)
      classes = null;
    if (className === void 0)
      className = null;
    if (init === void 0)
      init = null;
    var typeaheadRemoteInput = new TypeaheadRemoteInput(serviceManager, function_0, stateFunction, items, minLength, delay, type, value, taAjaxOptions, classes != null ? classes : get_set(className), init);
    $receiver.add_87eobz$(typeaheadRemoteInput);
    return typeaheadRemoteInput;
  }
  var package$io = _.io || (_.io = {});
  var package$kvision = package$io.kvision || (package$io.kvision = {});
  var package$form = package$kvision.form || (package$kvision.form = {});
  var package$text = package$form.text || (package$form.text = {});
  package$text.TypeaheadRemote = TypeaheadRemote;
  package$text.typeaheadRemote_4f4rz9$ = typeaheadRemote;
  $$importsForInline$$['kotlinx-serialization-kotlinx-serialization-core-jsLegacy'] = $module$kotlinx_serialization_kotlinx_serialization_core_jsLegacy;
  package$text.TypeaheadRemoteInput = TypeaheadRemoteInput;
  package$text.typeaheadRemoteInput_sw6uz7$ = typeaheadRemoteInput;
  Kotlin.defineModule('kvision-kvision-bootstrap-typeahead-remote-jsLegacy', _);
  return _;
}));

==> kvision-bootstrap-typeahead-remote-4.1.1.jar: kvision-kvision-bootstrap-typeahead-remote-jsLegacy.js <==
(function (root, factory) {
  if (typeof define === 'function' && define.amd)
    define(['exports', 'kotlin', 'kvision-jsLegacy', 'kvision-kvision-bootstrap-typeahead-jsLegacy', 'kvision-kvision-common-remote-jsLegacy', 'kotlinx-serialization-kotlinx-serialization-core-jsLegacy'], factory);
  else if (typeof exports === 'object')
    factory(module.exports, require('kotlin'), require('kvision-jsLegacy'), require('kvision-kvision-bootstrap-typeahead-jsLegacy'), require('kvision-kvision-common-remote-jsLegacy'), require('kotlinx-serialization-kotlinx-serialization-core-jsLegacy'));
  else {
    if (typeof kotlin === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-bootstrap-typeahead-remote-jsLegacy'. Its dependency 'kotlin' was not found. Please, check whether 'kotlin' is loaded prior to 'kvision-kvision-bootstrap-typeahead-remote-jsLegacy'.");
    }if (typeof this['kvision-jsLegacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-bootstrap-typeahead-remote-jsLegacy'. Its dependency 'kvision-jsLegacy' was not found. Please, check whether 'kvision-jsLegacy' is loaded prior to 'kvision-kvision-bootstrap-typeahead-remote-jsLegacy'.");
    }if (typeof this['kvision-kvision-bootstrap-typeahead-jsLegacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-bootstrap-typeahead-remote-jsLegacy'. Its dependency 'kvision-kvision-bootstrap-typeahead-jsLegacy' was not found. Please, check whether 'kvision-kvision-bootstrap-typeahead-jsLegacy' is loaded prior to 'kvision-kvision-bootstrap-typeahead-remote-jsLegacy'.");
    }if (typeof this['kvision-kvision-common-remote-jsLegacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-bootstrap-typeahead-remote-jsLegacy'. Its dependency 'kvision-kvision-common-remote-jsLegacy' was not found. Please, check whether 'kvision-kvision-common-remote-jsLegacy' is loaded prior to 'kvision-kvision-bootstrap-typeahead-remote-jsLegacy'.");
    }if (typeof this['kotlinx-serialization-kotlinx-serialization-core-jsLegacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-bootstrap-typeahead-remote-jsLegacy'. Its dependency 'kotlinx-serialization-kotlinx-serialization-core-jsLegacy' was not found. Please, check whether 'kotlinx-serialization-kotlinx-serialization-core-jsLegacy' is loaded prior to 'kvision-kvision-bootstrap-typeahead-remote-jsLegacy'.");
    }root['kvision-kvision-bootstrap-typeahead-remote-jsLegacy'] = factory(typeof this['kvision-kvision-bootstrap-typeahead-remote-jsLegacy'] === 'undefined' ? {} : this['kvision-kvision-bootstrap-typeahead-remote-jsLegacy'], kotlin, this['kvision-jsLegacy'], this['kvision-kvision-bootstrap-typeahead-jsLegacy'], this['kvision-kvision-common-remote-jsLegacy'], this['kotlinx-serialization-kotlinx-serialization-core-jsLegacy']);
  }
}(this, function (_, Kotlin, $module$kvision_jsLegacy, $module$kvision_kvision_bootstrap_typeahead_jsLegacy, $module$kvision_kvision_common_remote_jsLegacy, $module$kotlinx_serialization_kotlinx_serialization_core_jsLegacy) {
  'use strict';
  var $$importsForInline$$ = _.$$importsForInline$$ || (_.$$importsForInline$$ = {});
  var TextInputType = $module$kvision_jsLegacy.io.kvision.form.text.TextInputType;
  var AbstractText = $module$kvision_jsLegacy.io.kvision.form.text.AbstractText;
  var Kind_CLASS = Kotlin.Kind.CLASS;
  var TypeaheadInput = $module$kvision_kvision_bootstrap_typeahead_jsLegacy.io.kvision.form.text.TypeaheadInput;
  var TaAjaxOptions = $module$kvision_kvision_bootstrap_typeahead_jsLegacy.io.kvision.form.text.TaAjaxOptions;
  var drop = Kotlin.kotlin.text.drop_6ic1pp$;
  var utils = $module$kvision_jsLegacy.io.kvision.utils;
  var listOf = Kotlin.kotlin.collections.listOf_i5x0yv$;
  var JsonRpcRequest = $module$kvision_kvision_common_remote_jsLegacy.io.kvision.remote.JsonRpcRequest;
  var getKClass = Kotlin.getKClass;
  var createKType = Kotlin.createKType;
  var kotlin_js_internal_StringCompanionObject = Kotlin.kotlin.js.internal.StringCompanionObject;
  var serializer = $module$kotlinx_serialization_kotlinx_serialization_core_jsLegacy.kotlinx.serialization.builtins.serializer_6eet4j$;
  var ListSerializer = $module$kotlinx_serialization_kotlinx_serialization_core_jsLegacy.kotlinx.serialization.builtins.ListSerializer_swdriu$;
  var HttpType$valueOf = $module$kvision_kvision_bootstrap_typeahead_jsLegacy.io.kvision.form.text.HttpType.valueOf_61zpoe$;
  var get_set = $module$kvision_jsLegacy.io.kvision.utils.get_set_5cw0du$;
  var emptySet = Kotlin.kotlin.collections.emptySet_287e2$;
  var serializer_0 = $module$kotlinx_serialization_kotlinx_serialization_core_jsLegacy.kotlinx.serialization.serializer_ca95z9$;
  var KSerializer = $module$kotlinx_serialization_kotlinx_serialization_core_jsLegacy.kotlinx.serialization.KSerializer;
  var throwCCE = Kotlin.throwCCE;
  var copyToArray = Kotlin.kotlin.collections.copyToArray;
  TypeaheadRemote.prototype = Object.create(AbstractText.prototype);
  TypeaheadRemote.prototype.constructor = TypeaheadRemote;
  TypeaheadRemoteInput.prototype = Object.create(TypeaheadInput.prototype);
  TypeaheadRemoteInput.prototype.constructor = TypeaheadRemoteInput;
  function TypeaheadRemote(serviceManager, function_0, stateFunction, items, minLength, delay, type, value, name, label, rich, init) {
    if (stateFunction === void 0)
      stateFunction = null;
    if (items === void 0)
      items = 8;
    if (minLength === void 0)
      minLength = 1;
    if (delay === void 0)
      delay = 0;
    if (type === void 0)
      type = TextInputType.TEXT;
    if (value === void 0)
      value = null;
    if (name === void 0)
      name = null;
    if (label === void 0)
      label = null;
    if (rich === void 0)
      rich = false;
    if (init === void 0)
      init = null;
    AbstractText.call(this, label, rich);
    this.stateFunction_xn32t0$_0 = stateFunction;
    var $receiver = new TypeaheadRemoteInput(serviceManager, function_0, this.stateFunction_xn32t0$_0, items, minLength, delay, type, value);
    var closure$name = name;
    $receiver.id = this.idc;
    $receiver.name = closure$name;
    this.input_rigeej$_0 = $receiver;
    this.input.eventTarget = this;
    this.addPrivate_87eobz$(this.input);
    this.addPrivate_87eobz$(this.invalidFeedback);
    init != null ? init(this) : null;
  }
  Object.defineProperty(TypeaheadRemote.prototype, 'items', {
    configurable: true,
    get: function () {
      return this.input.items;
    },
    set: function (value) {
      this.input.items = value;
    }
  });
  Object.defineProperty(TypeaheadRemote.prototype, 'minLength', {
    configurable: true,
    get: function () {
      return this.input.minLength;
    },
    set: function (value) {
      this.input.minLength = value;
    }
  });
  Object.defineProperty(TypeaheadRemote.prototype, 'showHintOnFocus', {
    configurable: true,
    get: function () {
      return this.input.showHintOnFocus;
    },
    set: function (value) {
      this.input.showHintOnFocus = value;
    }
  });
  Object.defineProperty(TypeaheadRemote.prototype, 'autoSelect', {
    configurable: true,
    get: function () {
      return this.input.autoSelect;
    },
    set: function (value) {
      this.input.autoSelect = value;
    }
  });
  Object.defineProperty(TypeaheadRemote.prototype, 'delay', {
    configurable: true,
    get: function () {
      return this.input.taAjaxOptions;
    },
    set: function (value) {
      this.input.taAjaxOptions = value;
    }
  });
  Object.defineProperty(TypeaheadRemote.prototype, 'fitToElement', {
    configurable: true,
    get: function () {
      return this.input.fitToElement;
    },
    set: function (value) {
      this.input.fitToElement = value;
    }
  });
  Object.defineProperty(TypeaheadRemote.prototype, 'type', {
    configurable: true,
    get: function () {
      return this.input.type;
    },
    set: function (value) {
      this.input.type = value;
    }
  });
  Object.defineProperty(TypeaheadRemote.prototype, 'autocomplete', {
    configurable: true,
    get: function () {
      return this.input.autocomplete;
    },
    set: function (value) {
      this.input.autocomplete = value;
    }
  });
  Object.defineProperty(TypeaheadRemote.prototype, 'input', {
    configurable: true,
    get: function () {
      return this.input_rigeej$_0;
    }
  });
  TypeaheadRemote.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'TypeaheadRemote',
    interfaces: [AbstractText]
  };
  function typeaheadRemote($receiver, serviceManager, function_0, stateFunction, items, minLength, delay, type, value, name, label, rich, init) {
    if (stateFunction === void 0)
      stateFunction = null;
    if (items === void 0)
      items = 8;
    if (minLength === void 0)
      minLength = 1;
    if (delay === void 0)
      delay = 0;
    if (type === void 0)
      type = TextInputType.TEXT;
    if (value === void 0)
      value = null;
    if (name === void 0)
      name = null;
    if (label === void 0)
      label = null;
    if (rich === void 0)
      rich = false;
    if (init === void 0)
      init = null;
    var typeaheadRemote = new TypeaheadRemote(serviceManager, function_0, stateFunction, items, minLength, delay, type, value, name, label, rich, init);
    $receiver.add_87eobz$(typeaheadRemote);
    return typeaheadRemote;
  }
  function TypeaheadRemoteInput(serviceManager, function_0, stateFunction, items, minLength, delay, type, value, taAjaxOptions, classes, init) {
    if (stateFunction === void 0)
      stateFunction = null;
    if (items === void 0)
      items = 8;
    if (minLength === void 0)
      minLength = 1;
    if (delay === void 0)
      delay = 0;
    if (type === void 0)
      type = TextInputType.TEXT;
    if (value === void 0)
      value = null;
    if (taAjaxOptions === void 0)
      taAjaxOptions = null;
    if (classes === void 0) {
      classes = emptySet();
    }if (init === void 0)
      init = null;
    TypeaheadInput.call(this, null, null, null, items, minLength, delay, type, value, classes);
    this.stateFunction_7p3yg8$_0 = stateFunction;
    this.kvUrlPrefix_6kah5n$_0 = window['kv_remote_url_prefix'];
    this.urlPrefix_c4c7g0$_0 = this.kvUrlPrefix_6kah5n$_0 != undefined ? this.kvUrlPrefix_6kah5n$_0.toString() + '/' : '';
    var tmp$ = serviceManager.requireCall_lefff9$(function_0);
    var url = tmp$.component1()
    , method = tmp$.component2();
    var tempAjaxOptions = taAjaxOptions != null ? taAjaxOptions : new TaAjaxOptions();
    this.taAjaxOptions = tempAjaxOptions.copy_e0rzf$(this.urlPrefix_c4c7g0$_0 + drop(url, 1), TypeaheadRemoteInput_init$lambda(this, url), TypeaheadRemoteInput_init$lambda_0, void 0, HttpType$valueOf(method.name));
    init != null ? init(this) : null;
  }
  function TypeaheadRemoteInput_init$lambda(this$TypeaheadRemoteInput, closure$url) {
    return function (query) {
      var tmp$, tmp$_0;
      var squery = JSON.stringify(query);
      var state = (tmp$_0 = (tmp$ = this$TypeaheadRemoteInput.stateFunction_7p3yg8$_0) != null ? tmp$() : null) != null ? JSON.stringify(tmp$_0) : null;
      var $receiver = utils.JSON.plain;
      var value = new JsonRpcRequest(0, closure$url, listOf([squery, state]));
      var tmp$_1;
      return $receiver.encodeToString_tf03ej$(Kotlin.isType(tmp$_1 = serializer_0($receiver.serializersModule, createKType(getKClass(JsonRpcRequest), [], false)), KSerializer) ? tmp$_1 : throwCCE(), value);
    };
  }
  function TypeaheadRemoteInput_init$lambda_0(it) {
    return copyToArray(utils.JSON.plain.decodeFromString_awif5v$(ListSerializer(serializer(kotlin_js_internal_StringCompanionObject)), it.result));
  }
  TypeaheadRemoteInput.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'TypeaheadRemoteInput',
    interfaces: [TypeaheadInput]
  };
  function typeaheadRemoteInput($receiver, serviceManager, function_0, stateFunction, items, minLength, delay, type, value, taAjaxOptions, classes, className, init) {
    if (stateFunction === void 0)
      stateFunction = null;
    if (items === void 0)
      items = 8;
    if (minLength === void 0)
      minLength = 1;
    if (delay === void 0)
      delay = 0;
    if (type === void 0)
      type = TextInputType.TEXT;
    if (value === void 0)
      value = null;
    if (taAjaxOptions === void 0)
      taAjaxOptions = null;
    if (classes === void 0)
      classes = null;
    if (className === void 0)
      className = null;
    if (init === void 0)
      init = null;
    var typeaheadRemoteInput = new TypeaheadRemoteInput(serviceManager, function_0, stateFunction, items, minLength, delay, type, value, taAjaxOptions, classes != null ? classes : get_set(className), init);
    $receiver.add_87eobz$(typeaheadRemoteInput);
    return typeaheadRemoteInput;
  }
  var package$io = _.io || (_.io = {});
  var package$kvision = package$io.kvision || (package$io.kvision = {});
  var package$form = package$kvision.form || (package$kvision.form = {});
  var package$text = package$form.text || (package$form.text = {});
  package$text.TypeaheadRemote = TypeaheadRemote;
  package$text.typeaheadRemote_4f4rz9$ = typeaheadRemote;
  $$importsForInline$$['kotlinx-serialization-kotlinx-serialization-core-jsLegacy'] = $module$kotlinx_serialization_kotlinx_serialization_core_jsLegacy;
  package$text.TypeaheadRemoteInput = TypeaheadRemoteInput;
  package$text.typeaheadRemoteInput_sw6uz7$ = typeaheadRemoteInput;
  Kotlin.defineModule('kvision-kvision-bootstrap-typeahead-remote-jsLegacy', _);
  return _;
}));
